Documentation
¶
Overview ¶
Package runes provides interfaces and utilities for working with runes.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Buffer ¶
Buffer is an interface for accessing a contiguous array of code points.
func NewBuffer ¶
NewBuffer returns an efficient implementation of Buffer for the given text based on the ranges of the encoded code points contained within.
func NewBufferAndLineOffsets ¶
NewBufferAndLineOffsets returns an efficient implementation of Buffer for the given text based on the ranges of the encoded code points contained within, as well as returning the line offsets.
type SizeLimitError ¶
SizeLimitError indicates that the input exceeded the configured code point limit.
func (*SizeLimitError) Error ¶
func (e *SizeLimitError) Error() string
Click to show internal directories.
Click to hide internal directories.